# Contact
It takes contact list and saves in the database or on entering the number returns the name if the number is found in the database.

## Installation
```pip install contact```

## How to use it?
Open terminal and type contact and then input the integer of your choice

## License

© 2022 Abhishek Pandey

This repository is licensed under the MIT license. See LICENSE for details.